@@ -2,22 +2,21 @@ from pywork.modules.sort_to_high import Sth
 
 class Bs:
 
-    def __init__ (self, arr, item):
-        self.arr = arr
-        self.item = item
+    def __init__ (self):
+        pass
 
-    def search(self):
+    def search(self, arr, item):
         low = 0
-        high = len(self.arr) - 1
-        list = Sth(self.arr).sort()
+        high = len(arr) - 1
+        list = Sth().sort(arr)
 
         while low <= high:
             mid = (low + high)
             guess = list[mid]
 
-            if guess == self.item:
+            if guess == item:
                 return mid
-            if guess > self.item:
+            if guess > item:
                 high = mid - 1
             else:
                 low = mid + 1 
